@@ -82,9 +82,9 @@ FILE = Field(..., name='Table')
 PK01 = Field(..., name='Primary key 1')
 PK02 = Field('', name='Primary key 2')
 PK03 = Field('', name='Primary key 3')
-N096 = Field(0, name='Numeric field')
-N196 = Field(0, name='Numeric field')
-N296 = Field(0, name='Numeric field')
+N096 = Field(None, name='Numeric field')
+N196 = Field(None, name='Numeric field')
+N296 = Field(None, name='Numeric field')
 TX40 = Field(..., name='Description')
 TX15 = Field(..., name='Name')
 RESP = Field(..., name='Responsible')
@@ -243,7 +243,6 @@ class CustomerExtension(BaseModel):
     N296: Optional[NonNegativeInt] = N296
 
 
-
 class CustomerExtensionExtended(BaseModel):
     _api: str = PrivateAttr(default='API_CUSEXTMI_ChgFieldValueEx')
     Message: Optional[str] = Message
